@@ -27,8 +27,7 @@ pub fn main(args: &[&str]) -> Result<()> {
         println!("Missing arguments <par-file> <k=5>!");
         println!(
             "Example:\n\
-            cargo run --bin {} ./src/parser/parol-grammar-exp.par",
-            module_path!()
+            cargo run --bin parol calculate_k ./src/parser/parol-grammar-exp.par"
         );
     }
     Ok(())
