@@ -5,17 +5,11 @@ use parol::generators::generate_terminal_names;
 use parol::{obtain_grammar_config, MAX_K};
 
 pub fn main(args: &[&str]) -> Result<()> {
-    // NOTE: Logger already initalized
-    // env_logger::init();
-    // $env:RUST_LOG="parol,parol_runtime=off,productivity=debug"
-    // debug!("env logger started");
-
     if args.len() < 2 {
         println!("Missing arguments <par-file> [k=1]!");
         println!(
             "Example:\n\
-            cargo run --bin {} ./src/parser/parol-grammar-exp.par",
-            module_path!()
+            cargo run --bin parol follow ./src/parser/parol-grammar-exp.par"
         );
     } else {
         let file_name = args[1].to_owned();
